==> content_snapshot-3.0.2.tar.gz: content_snapshot/src/ContentProvider/ContentEntityProvider.php <==
<?php

namespace Drupal\content_snapshot\ContentProvider;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Implements Class ContentEntityProvider.
 */
class ContentEntityProvider implements ContentEntityProviderInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityTypeManager;

  /**
   * ContentEntityProvider constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   Returns Entity Interface.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function provide(): array {
    $entities = [];

    $entityTypeDefinations = $this->entityTypeManager->getDefinitions();
    foreach ($entityTypeDefinations as $entityTypeId => $definition) {
      if ($definition->entityClassImplements(ContentEntityInterface::class)) {
        $loaded = $this->entityTypeManager->getStorage($entityTypeId)->loadMultiple();

        if ($entityTypeId === 'user') {
          // Do not export anonymous user and admin.
          unset($loaded[0]);
        }

        $entities = array_merge($entities, $loaded);
      }
    }

    return $entities;
  }

}

==> content_snapshot-3.0.3.tar.gz: content_snapshot/src/ContentProvider/ContentEntityProvider.php <==
<?php

namespace Drupal\content_snapshot\ContentProvider;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Implements Class ContentEntityProvider.
 */
class ContentEntityProvider implements ContentEntityProviderInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityTypeManager;

  /**
   * ContentEntityProvider constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   Returns Entity Interface.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function provide(): array {
    $entities = [];

    $entityTypeDefinitions = $this->entityTypeManager->getDefinitions();
    foreach ($entityTypeDefinitions as $entityTypeId => $definition) {
      if ($definition->entityClassImplements(ContentEntityInterface::class)) {
        $loaded = $this->entityTypeManager->getStorage($entityTypeId)->loadMultiple();

        if ($entityTypeId === 'user') {
          // Do not export anonymous user and admin.
          unset($loaded[0]);
        }

        $entities = array_merge($entities, $loaded);
      }
    }

    return $entities;
  }

}
